@@ -1,8 +1,8 @@
 from . import _LOGGER
 
 from .device import _WiserDevice
-from .helpers import _WiserBattery
-from .helpers import _WiserTemperatureFunctions as tf
+from .helpers.battery import _WiserBattery
+from .helpers.temp import _WiserTemperatureFunctions as tf
 from .rest_controller import _WiserRestController
 
 from .const import (
